;/**
; *******************************************************************************
; * @file        a34m456_startup.s
; * @author      ABOV R&D Division
; * @brief       CMSIS Core Device Startup File for A34M456
; *
; * Copyright 2024 ABOV Semiconductor Co.,Ltd. All rights reserved.
; *
; * This file is licensed under terms that are found in the LICENSE file
; * located at Document directory.
; * If this file is delivered or shared without applicable license terms,
; * the terms of the BSD-3-Clause license shall be applied.
; * Reference: https://opensource.org/licenses/BSD-3-Clause
; ******************************************************************************/

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000400

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp

; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                EXPORT  __Vectors_End
                EXPORT  __Vectors_Size

__Vectors      
                DCD     __initial_sp                ; Top of Stack
                DCD     Reset_Handler               ; Reset Handler
                DCD     NMI_Handler                 ; NMI Handler
                DCD     HardFault_Handler           ; Hard Fault Handler
                DCD     MemManage_Handler           ; MPU Fault Handler
                DCD     BusFault_Handler            ; Bus Fault Handler
                DCD     UsageFault_Handler          ; Usage Fault Handler
                DCD     0                           ; Reserved
                DCD     0                           ; Reserved
                DCD     0                           ; Reserved
                DCD     0                           ; Reserved
                DCD     SVC_Handler                 ; SVCall Handler
                DCD     DebugMon_Handler            ; Debug Monitor Handler
                DCD     0                           ; Reserved
                DCD     PendSV_Handler              ; PendSV Handler
                DCD     SysTick_Handler             ; SysTick Handler

                ; External Interrupts
                DCD     LVI_IRQHandler              ;  0: LVI
                DCD     SYSCLKFAIL_IRQHandler       ;  1: SYSCLKFAIL
                DCD     HSEFAIL_IRQHandler          ;  2: HSEFAIL
                DCD     LSEFAIL_IRQHandler          ;  3: LSEFAIL
                DCD     0                           ;  4: Reserved
                DCD     0                           ;  5: Reserved
                DCD     WDT_IRQHandler              ;  6: WDT
                DCD     0                           ;  7: Reserved
                DCD     FRT0_IRQHandler             ;  8: FRT0
                DCD     FRT1_IRQHandler             ;  9: FRT1
                DCD     0                           ; 10: Reserved
                DCD     CFMC_IRQHandler             ; 11: CFMC
                DCD     DFMC_IRQHandler             ; 12: DFMC
                DCD     0                           ; 13: Reserved
                DCD     0                           ; 14: Reserved
                DCD     TIMER0_IRQHandler           ; 15: TIMER0
                DCD     TIMER1_IRQHandler           ; 16: TIMER1
                DCD     TIMER2_IRQHandler           ; 17: TIMER2
                DCD     TIMER3_IRQHandler           ; 18: TIMER3
                DCD     TIMER4_IRQHandler           ; 19: TIMER4
                DCD     TIMER5_IRQHandler           ; 20: TIMER5
                DCD     TIMER6_IRQHandler           ; 21: TIMER6
                DCD     TIMER7_IRQHandler           ; 22: TIMER7
                DCD     TIMER8_IRQHandler           ; 23: TIMER8
                DCD     TIMER9_IRQHandler           ; 24: TIMER9
                DCD     0                           ; 25: Reserved
                DCD     0                           ; 26: Reserved
                DCD     RNG_IRQHandler              ; 27: RNG
                DCD     0                           ; 28: Reserved
                DCD     0                           ; 29: Reserved
                DCD     0                           ; 30: Reserved
                DCD     0                           ; 31: Reserved
                DCD     0                           ; 32: Reserved
                DCD     PFCPPROT0_IRQHandler        ; 33: PFCPPROT0
                DCD     PFCPPROT1_IRQHandler        ; 34: PFCPPROT1
                DCD     PFCP_IRQHandler             ; 35: PFCP
                DCD     GPIOA_IRQHandler            ; 36: GPIOA
                DCD     GPIOB_IRQHandler            ; 37: GPIOB
                DCD     GPIOC_IRQHandler            ; 38: GPIOC
                DCD     GPIOD_IRQHandler            ; 39: GPIOD
                DCD     GPIOE_IRQHandler            ; 40: GPIOE
                DCD     GPIOF_IRQHandler            ; 41: GPIOF
                DCD     0                           ; 42: Reserved
                DCD     0                           ; 43: Reserved
                DCD     0                           ; 44: Reserved
                DCD     MPWM0PROT_IRQHandler        ; 45: MPWM0PROT
                DCD     MPWM0OC_IRQHandler          ; 46: MPWM0OC
                DCD     MPWM0_IRQHandler            ; 47: MPWM0
                DCD     0                           ; 48: Reserved
                DCD     0                           ; 49: Reserved
                DCD     MPWM1PROT_IRQHandler        ; 50: MPWM1PROT
                DCD     MPWM1OC_IRQHandler          ; 51: MPWM1OC
                DCD     MPWM1_IRQHandler            ; 52: MPWM1
                DCD     0                           ; 53: Reserved
                DCD     0                           ; 54: Reserved
                DCD     SPI0_IRQHandler             ; 55: SPI0
                DCD     SPI1_IRQHandler             ; 56: SPI1
                DCD     0                           ; 57: Reserved
                DCD     0                           ; 58: Reserved
                DCD     0                           ; 59: Reserved
                DCD     I2C0_IRQHandler             ; 60: I2C0
                DCD     I2C1_IRQHandler             ; 61: I2C1
                DCD     0                           ; 62: Reserved
                DCD     UART0_IRQHandler            ; 63: UART0
                DCD     UART1_IRQHandler            ; 64: UART1
                DCD     UART2_IRQHandler            ; 65: UART2
                DCD     UART3_IRQHandler            ; 66: UART3
                DCD     UART4_IRQHandler            ; 67: UART4
                DCD     UART5_IRQHandler            ; 68: UART5
                DCD     0                           ; 69: Reserved
                DCD     0                           ; 70: Reserved
                DCD     0                           ; 71: Reserved
                DCD     0                           ; 72: Reserved
                DCD     0                           ; 73: Reserved
                DCD     ADC0_IRQHandler             ; 74: ADC0
                DCD     ADC1_IRQHandler             ; 75: ADC1
                DCD     ADC2_IRQHandler             ; 76: ADC2
                DCD     0                           ; 77: Reserved
                DCD     0                           ; 78: Reserved
                DCD     CMP0_IRQHandler             ; 79: CMP0
                DCD     CMP1_IRQHandler             ; 80: CMP1
                DCD     CMP2_IRQHandler             ; 81: CMP2
                DCD     CMP3_IRQHandler             ; 82: CMP3
                DCD     0                           ; 83: Reserved
                DCD     0                           ; 84: Reserved
                DCD     CRC_IRQHandler              ; 85: CRC

__Vectors_End

__Vectors_Size  EQU     __Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main

                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_HandlerC\
                PROC
                EXPORT  HardFault_HandlerC        [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                MOVS    R0, #4
                MOV     R1, LR
                TST     R0, R1
                BEQ     __HardFault_MSP
                MRS     R0, PSP
                LDR     R1,=HardFault_HandlerC
                BX      R1
__HardFault_MSP
                MRS     R0, MSP
                LDR     R1,=HardFault_HandlerC
                BX      R1
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler\
                PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler\
                PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

NULL_IRQHandler PROC
                EXPORT  LVI_IRQHandler            [WEAK]
                EXPORT  SYSCLKFAIL_IRQHandler     [WEAK]
                EXPORT  HSEFAIL_IRQHandler        [WEAK]
                EXPORT  LSEFAIL_IRQHandler        [WEAK]
                EXPORT  WDT_IRQHandler            [WEAK]
                EXPORT  FRT0_IRQHandler           [WEAK]
                EXPORT  FRT1_IRQHandler           [WEAK]
                EXPORT  CFMC_IRQHandler           [WEAK]
                EXPORT  DFMC_IRQHandler           [WEAK]
                EXPORT  TIMER0_IRQHandler         [WEAK]
                EXPORT  TIMER1_IRQHandler         [WEAK]
                EXPORT  TIMER2_IRQHandler         [WEAK]
                EXPORT  TIMER3_IRQHandler         [WEAK]
                EXPORT  TIMER4_IRQHandler         [WEAK]
                EXPORT  TIMER5_IRQHandler         [WEAK]
                EXPORT  TIMER6_IRQHandler         [WEAK]
                EXPORT  TIMER7_IRQHandler         [WEAK]
                EXPORT  TIMER8_IRQHandler         [WEAK]
                EXPORT  TIMER9_IRQHandler         [WEAK]
                EXPORT  RNG_IRQHandler            [WEAK]
                EXPORT  PFCPPROT0_IRQHandler      [WEAK]
                EXPORT  PFCPPROT1_IRQHandler      [WEAK]
                EXPORT  PFCP_IRQHandler           [WEAK]
                EXPORT  GPIOA_IRQHandler          [WEAK]
                EXPORT  GPIOB_IRQHandler          [WEAK]
                EXPORT  GPIOC_IRQHandler          [WEAK]
                EXPORT  GPIOD_IRQHandler          [WEAK]
                EXPORT  GPIOE_IRQHandler          [WEAK]
                EXPORT  GPIOF_IRQHandler          [WEAK]
                EXPORT  MPWM0PROT_IRQHandler      [WEAK]
                EXPORT  MPWM0OC_IRQHandler        [WEAK]
                EXPORT  MPWM0_IRQHandler          [WEAK]
                EXPORT  MPWM1PROT_IRQHandler      [WEAK]
                EXPORT  MPWM1OC_IRQHandler        [WEAK]
                EXPORT  MPWM1_IRQHandler          [WEAK]
                EXPORT  SPI0_IRQHandler           [WEAK]
                EXPORT  SPI1_IRQHandler           [WEAK]
                EXPORT  I2C0_IRQHandler           [WEAK]
                EXPORT  I2C1_IRQHandler           [WEAK]
                EXPORT  UART0_IRQHandler          [WEAK]
                EXPORT  UART1_IRQHandler          [WEAK]
                EXPORT  UART2_IRQHandler          [WEAK]
                EXPORT  UART3_IRQHandler          [WEAK]
                EXPORT  UART4_IRQHandler          [WEAK]
                EXPORT  UART5_IRQHandler          [WEAK]
                EXPORT  ADC0_IRQHandler           [WEAK]
                EXPORT  ADC1_IRQHandler           [WEAK]
                EXPORT  ADC2_IRQHandler           [WEAK]
                EXPORT  CMP0_IRQHandler           [WEAK]
                EXPORT  CMP1_IRQHandler           [WEAK]
                EXPORT  CMP2_IRQHandler           [WEAK]
                EXPORT  CMP3_IRQHandler           [WEAK]
                EXPORT  CRC_IRQHandler            [WEAK]


LVI_IRQHandler
SYSCLKFAIL_IRQHandler
HSEFAIL_IRQHandler
LSEFAIL_IRQHandler
WDT_IRQHandler
FRT0_IRQHandler
FRT1_IRQHandler
CFMC_IRQHandler
DFMC_IRQHandler
TIMER0_IRQHandler
TIMER1_IRQHandler
TIMER2_IRQHandler
TIMER3_IRQHandler
TIMER4_IRQHandler
TIMER5_IRQHandler
TIMER6_IRQHandler
TIMER7_IRQHandler
TIMER8_IRQHandler
TIMER9_IRQHandler
RNG_IRQHandler
PFCPPROT0_IRQHandler
PFCPPROT1_IRQHandler
PFCP_IRQHandler
GPIOA_IRQHandler
GPIOB_IRQHandler
GPIOC_IRQHandler
GPIOD_IRQHandler
GPIOE_IRQHandler
GPIOF_IRQHandler
MPWM0PROT_IRQHandler
MPWM0OC_IRQHandler
MPWM0_IRQHandler
MPWM1PROT_IRQHandler
MPWM1OC_IRQHandler
MPWM1_IRQHandler
SPI0_IRQHandler
SPI1_IRQHandler
I2C0_IRQHandler
I2C1_IRQHandler
UART0_IRQHandler
UART1_IRQHandler
UART2_IRQHandler
UART3_IRQHandler
UART4_IRQHandler
UART5_IRQHandler
ADC0_IRQHandler
ADC1_IRQHandler
ADC2_IRQHandler
CMP0_IRQHandler
CMP1_IRQHandler
CMP2_IRQHandler
CMP3_IRQHandler
CRC_IRQHandler

                B       .
                ENDP

                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap

__user_initial_stackheap PROC
                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR
                ENDP

                ALIGN

                ENDIF


                END

