/**
 *******************************************************************************
 * @file        a34m456_system.c
 * @author      ABOV R&D Division
 * @brief       System configuration
 *
 * Copyright 2024 ABOV Semiconductor Co.,Ltd. All rights reserved.
 *
 * This file is licensed under terms that are found in the LICENSE file
 * located at Document directory.
 * If this file is delivered or shared without applicable license terms,
 * the terms of the BSD-3-Clause license shall be applied.
 * Reference: https://opensource.org/licenses/BSD-3-Clause
 ******************************************************************************/


#include "a34m456.h"
#include "a34m456_system.h"

#define A34M456_DEFAULT_CORE_CLOCK      (8000000)/* 8MHz */
#define A34M456_DEFAULT_PERI_CLOCK      (8000000)/* 8MHz */
#define A34M456_DEFAULT_MAIN_CLOCK      (8000000)/* 8MHz */

uint32_t SystemCoreClock = A34M456_DEFAULT_CORE_CLOCK;   /* 8MHz */
uint32_t SystemPeriClock = A34M456_DEFAULT_PERI_CLOCK;   /* 8MHz */
uint32_t SystemDelayCount;

void SystemInit(void) 
{
    uint32_t reg;

    __disable_irq();

#if (__FPU_PRESENT == 1) && (__FPU_USED == 1)
    /* Set bits 20-23 to enable CP10 and CP11 coprocessors */
    SCB->CPACR |= (0x0FUL << 20UL);
#endif

    /* WDT Access Enable */
    WDT->AEN = 0xA55A;
    /* WDT Disable */
    WDT->CON = 0;

    /* SCU Access Enable */
    SCU->SYSTEN = 0x57;
    SCU->SYSTEN = 0x75;

    /* GPIO Access Enable */
    PORTEN->EN = 0x15;
    PORTEN->EN = 0x51;

    SystemCoreClock = A34M456_DEFAULT_CORE_CLOCK;   /* 8MHz */
    SystemPeriClock = A34M456_DEFAULT_PERI_CLOCK;   /* 8MHz */
    /* hclk = mclk, pclk = hclk */
    reg = SCU->SCCR;
    reg &= ~SCU_SCCR_HCLKDIV_Msk;
    reg &= ~SCU_SCCR_PCLKDIV_Msk;
    SCU->SCCR = reg;

    /* Instruction Cache Disable */
    CFMC->CONF &= ~(CFMC_CONF_DCEN_Msk | CFMC_CONF_ICEN_Msk);

    /* Instruction Cache Reset */
    CFMC->CTRL |= ((0x01UL << CFMC_CTRL_DCRST_Pos) | (0x01UL << CFMC_CTRL_ICRST_Pos));

    /* Enable data/instruction cache */
    /* During IC evaluation, This code will be moved after clock setting */
    CFMC->CONF |= ((0x01UL << CFMC_CONF_DCEN_Pos) | (0x01UL << CFMC_CONF_ICEN_Pos));
   
   /* Flash Wait 4 */
    reg = CFMC->CONF;
    reg &= ~(CFMC_CONF_LATENCY_Msk);
    reg |= (0x04UL << CFMC_CONF_LATENCY_Pos);
    CFMC->CONF = reg;

    __enable_irq();
}

void SystemDelay(uint32_t ms)
{
    volatile uint32_t i;

    for (i = 0; i < (SystemDelayCount * ms); i++)
    {
        __NOP();
    }
}
