/**
 *******************************************************************************
 * @file        a34m456_dac.h
 * @author      ABOV R&D Division
 * @brief       DAC driver
 *
 * Copyright 2024 ABOV Semiconductor Co.,Ltd. All rights reserved.
 *
 * This file is licensed under terms that are found in the LICENSE file
 * located at Document directory.
 * If this file is delivered or shared without applicable license terms,
 * the terms of the BSD-3-Clause license shall be applied.
 * Reference: https://opensource.org/licenses/BSD-3-Clause
 ******************************************************************************/

/**
 * @addtogroup  driver
 * @{
 * @defgroup    driver_dac DAC
 * @{
 * @brief       DAC driver
 */

  
#ifndef _A34M456_DAC_H_
#define _A34M456_DAC_H_

#ifdef __cplusplus
extern "C"
{
#endif
    
#include <stdint.h>
#include "a34m456_driver_common.h"

/**
 * DAC id
*/
enum dac_id
{
    DAC_ID_0,                   /**< DAC 0 */
    DAC_ID_1,                   /**< DAC 1 */    
    DAC_ID_MAX,                 /**< DAC max */
};

/**
 * DAC out
*/
enum dac_out
{
    DAC_OUT_DISABLE,                               /**< DAC OUT DISABLE */
    DAC_OUT_ENABLE,                                /**< DAC OUT ENABLE */
};

/**
 * DAC configuration
*/   
struct dac_cfg
{
    enum dac_out out;
};

/**
 *******************************************************************************
 * @brief       Initialize DAC.
 * @param[in]   id instance id
 * @param[in]   cfg configuration
 * @return      driver error code
 ******************************************************************************/
int32_t HAL_DAC_Init(enum dac_id id, struct dac_cfg *cfg);

/**
 *******************************************************************************
 * @brief       Start DAC.
 * @param[in]   id instance id
 * @return      driver error code
 ******************************************************************************/
int32_t HAL_DAC_Start(enum dac_id id);

/**
 *******************************************************************************
 * @brief       Stop DAC.
 * @param[in]   id instance id
 * @return      driver error code
 ******************************************************************************/
int32_t HAL_DAC_Stop(enum dac_id id);

/**
 *******************************************************************************
 * @brief       Set DAC data..
 * @param[in]   id instance id
 * @param[in]  data data
 * @return      driver error code
 ******************************************************************************/
int32_t HAL_DAC_SetData(enum dac_id id, uint32_t data);

/**
 *******************************************************************************
 * @brief       Get DAC data..
 * @param[in]   id instance id
 * @param[out]  data data
 * @return      driver error code
 ******************************************************************************/
int32_t HAL_DAC_GetData(enum dac_id id, uint32_t *data);


#ifdef __cplusplus
}
#endif

#endif /* _A34m456_DAC_H_ */

/** @} */
/** @} */

