/**
 *******************************************************************************
 * @file        a34m456_port_init.c
 * @author      ABOV R&D Division
 * @brief       Application specific port configuration
 *
 * Copyright 2024 ABOV Semiconductor Co.,Ltd. All rights reserved.
 *
 * This file is licensed under terms that are found in the LICENSE file
 * located at Document directory.
 * If this file is delivered or shared without applicable license terms,
 * the terms of the BSD-3-Clause license shall be applied.
 * Reference: https://opensource.org/licenses/BSD-3-Clause
 ******************************************************************************/

#include "main.h"

#include "a34m456_gpio.h"

void Port_Init(void)
{
    HAL_GPIO_Init();
    

    /* PORT A setting 
    PA15 : Output (Reserved)
    PA14 : SWDIO ()
    PA13 : Output (Reserved)
    PA12 : SWCLK ()
    PA11 : Output (Reserved)
    PA10 : Output (Reserved)
    PA9  : Output (Reserved)
    PA8  : XOUT
    PA7  : XIN
    PA6  : nRESET ()
    PA5  : Input ()
    PA4  : nBOOT (Reserved)
    PA3  : Output (Reserved)
    PA2  : Output (Reserved)
    PA1  : Output (Reserved)
    PA0  : Output (Reserved) */

    PA->MR2 = 0x00
            | (0x00UL << PCU_MR2_P15MUX_Pos) /* 0 : PA15,        1 :              2 :              3 :              4 :              7 :   */
            | (0x03UL << PCU_MR2_P14MUX_Pos) /* 0 : PA14,        1 :              2 :              3 : SWDIO,       4 :              7 :   */
            | (0x00UL << PCU_MR2_P13MUX_Pos) /* 0 : PA13,        1 : SCK1,        2 :              3 :              4 :              7 :   */
            | (0x03UL << PCU_MR2_P12MUX_Pos) /* 0 : PA12,        1 :              2 :              3 : SWCLK,       4 :              7 :   */
            | (0x00UL << PCU_MR2_P11MUX_Pos) /* 0 : PA11,        1 : SS1,         2 : T1IO,        3 : PFCPBO,      4 :              7 :   */
            | (0x00UL << PCU_MR2_P10MUX_Pos) /* 0 : PA10,        1 :              2 : T0IO,        3 : PFCPAO,      4 :              7 :   */
            | (0x00UL << PCU_MR2_P9MUX_Pos)  /* 0 : PA9,         1 :              2 :              3 : PFCPPRTIN,   4 :              7 :   */
            | (0x07UL << PCU_MR2_P8MUX_Pos); /* 0 : PA8,         1 :              2 :              3 :              4 :              7 : XOUT */

    PA->MR1 = 0x00
            | (0x07UL << PCU_MR1_P7MUX_Pos)  /* 0 : PA7,         1 :              2 :              3 :              4 :              7 : XIN */
            | (0x03UL << PCU_MR1_P6MUX_Pos)  /* 0 : PA6,         1 :              2 :              3 : nRESET,      4 :              7 :    */
            | (0x00UL << PCU_MR1_P5MUX_Pos)  /* 0 : PA5,         1 :              2 :              3 : PFCPOCIN,    4 :              7 :    */
            | (0x03UL << PCU_MR1_P4MUX_Pos)  /* 0 : PA4,         1 :              2 :              3 : nBOOT,       4 :              7 :    */
            | (0x00UL << PCU_MR1_P3MUX_Pos)  /* 0 : PA3,         1 :              2 :              3 :              4 :              7 :    */
            | (0x00UL << PCU_MR1_P2MUX_Pos)  /* 0 : PA2,         1 : MOSI1,       2 : SDA0,        3 : TXD1,        4 :              7 : SXOUT */
            | (0x00UL << PCU_MR1_P1MUX_Pos)  /* 0 : PA1,         1 : MISO1,       2 : SCL0,        3 : RXD1,        4 :              7 : SXIN */
            | (0x00UL << PCU_MR1_P0MUX_Pos); /* 0 : PA0,         1 : SS1,         2 : T8IO,        3 : WDTO,        4 :              7 : DACO */

    /* 0     : Push-pull output
       1     : Open-drain output
       2 / 3 : Input */
    PA->CR = 0x00
            | (0x00UL << PCU_CR_P15_Pos) /* PA15 */
            | (0x00UL << PCU_CR_P14_Pos) /* PA14 */
            | (0x00UL << PCU_CR_P13_Pos) /* PA13 */
            | (0x00UL << PCU_CR_P12_Pos) /* PA12 */
            | (0x00UL << PCU_CR_P11_Pos) /* PA11 */
            | (0x00UL << PCU_CR_P10_Pos) /* PA10 */
            | (0x00UL << PCU_CR_P9_Pos)  /* PA9 */
            | (0x00UL << PCU_CR_P8_Pos)  /* PA8 */
            | (0x03UL << PCU_CR_P7_Pos)  /* PA7 */
            | (0x03UL << PCU_CR_P6_Pos)  /* PA6 */
            | (0x00UL << PCU_CR_P5_Pos)  /* PA5 */
            | (0x03UL << PCU_CR_P4_Pos)  /* PA4 */
            | (0x00UL << PCU_CR_P3_Pos)  /* PA3 */
            | (0x00UL << PCU_CR_P2_Pos)  /* PA2 */
            | (0x00UL << PCU_CR_P1_Pos)  /* PA1 */
            | (0x00UL << PCU_CR_P0_Pos); /* PA0 */

    /* 0 / 1 : Disable pull-up/down resistor
           2 : Enable pull-up resistor
           3 : Enable Pull-down resistor */
    PA->PRCR = 0x00
            | (0x00UL << PCU_PRCR_PUE15_Pos) /* PA15 */
            | (0x02UL << PCU_PRCR_PUE14_Pos) /* PA14 */
            | (0x00UL << PCU_PRCR_PUE13_Pos) /* PA13 */
            | (0x02UL << PCU_PRCR_PUE12_Pos) /* PA12 */
            | (0x00UL << PCU_PRCR_PUE11_Pos) /* PA11 */
            | (0x00UL << PCU_PRCR_PUE10_Pos) /* PA10 */
            | (0x00UL << PCU_PRCR_PUE9_Pos)  /* PA9 */
            | (0x00UL << PCU_PRCR_PUE8_Pos)  /* PA8 */
            | (0x00UL << PCU_PRCR_PUE7_Pos)  /* PA7 */
            | (0x02UL << PCU_PRCR_PUE6_Pos)  /* PA6 */
            | (0x00UL << PCU_PRCR_PUE5_Pos)  /* PA5 */
            | (0x02UL << PCU_PRCR_PUE4_Pos)  /* PA4 */
            | (0x00UL << PCU_PRCR_PUE3_Pos)  /* PA3 */
            | (0x00UL << PCU_PRCR_PUE2_Pos)  /* PA2 */
            | (0x00UL << PCU_PRCR_PUE1_Pos)  /* PA1 */
            | (0x00UL << PCU_PRCR_PUE0_Pos); /* PA0 */


    /* PORT B setting
    PB15 : Output (Reserved)
    PB14 : Output (Reserved)
    PB13 : Output (Reserved)
    PB12 : Output (Reserved)
    PB11 : Output (Reserved)
    PB10 : Output (Reserved)
    PB9  : Output (Reserved)
    PB8  : Output (Reserved)
    PB7  : Output (Reserved)
    PB6  : Output (Reserved)
    PB5  : Output (Reserved)
    PB4  : Output (Reserved)
    PB3  : Output (Reserved)
    PB2  : Output (Reserved)
    PB1  : Output (Reserved)
    PB0  : Output (Reserved) */

    PB->MR2 = 0x00
            | (0x00UL << PCU_MR2_P15MUX_Pos) /* 0 : PB15,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P14MUX_Pos) /* 0 : PB14,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P13MUX_Pos) /* 0 : PB13,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P12MUX_Pos) /* 0 : PB12,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P11MUX_Pos) /* 0 : PB11,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P10MUX_Pos) /* 0 : PB10,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P9MUX_Pos)  /* 0 : PB9,         1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P8MUX_Pos); /* 0 : PB8,         1 :              2 :              3 :              4 :              7 : */

    PB->MR1 = 0x00
            | (0x00UL << PCU_MR1_P7MUX_Pos)  /* 0 : PB7,         1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P6MUX_Pos)  /* 0 : PB6,         1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P5MUX_Pos)  /* 0 : PB5,         1 : RXD3         2 : T2IO,        3 : SCL1,        4 : OCIN0,       7 : */
            | (0x00UL << PCU_MR1_P4MUX_Pos)  /* 0 : PB4,         1 : TXD3,        2 : T1IO,        3 : SDA1,        4 :              7 : */
            | (0x00UL << PCU_MR1_P3MUX_Pos)  /* 0 : PB3,         1 : SDA0         2 : T0IO,        3 : CLKO,        4 :              7 : */
            | (0x00UL << PCU_MR1_P2MUX_Pos)  /* 0 : PB2,         1 : SCL0,        2 :              3 : STBYO,       4 :              7 : */
            | (0x00UL << PCU_MR1_P1MUX_Pos)  /* 0 : PB1,         1 : TXD2         2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P0MUX_Pos); /* 0 : PB0,         1 : RXD2,        2 :              3 :              4 :              7 : */

    /* 0     : Push-pull output
       1     : Open-drain output
       2 / 3 : Input */
    PB->CR = 0x00
            | (0x00UL << PCU_CR_P15_Pos) /* PB15 */
            | (0x00UL << PCU_CR_P14_Pos) /* PB14 */
            | (0x00UL << PCU_CR_P13_Pos) /* PB13 */
            | (0x00UL << PCU_CR_P12_Pos) /* PB12 */
            | (0x00UL << PCU_CR_P11_Pos) /* PB11 */
            | (0x00UL << PCU_CR_P10_Pos) /* PB10 */
            | (0x00UL << PCU_CR_P9_Pos)  /* PB9 */
            | (0x00UL << PCU_CR_P8_Pos)  /* PB8 */
            | (0x00UL << PCU_CR_P7_Pos)  /* PB7 */
            | (0x00UL << PCU_CR_P6_Pos)  /* PB6 */
            | (0x00UL << PCU_CR_P5_Pos)  /* PB5 */
            | (0x00UL << PCU_CR_P4_Pos)  /* PB4 */
            | (0x00UL << PCU_CR_P3_Pos)  /* PB3 */
            | (0x00UL << PCU_CR_P2_Pos)  /* PB2 */
            | (0x00UL << PCU_CR_P1_Pos)  /* PB1 */
            | (0x00UL << PCU_CR_P0_Pos); /* PB0 */

    /* 0 / 1 : Disable pull-up/down resistor
           2 : Enable pull-up resistor
           3 : Enable Pull-down resistor */
    PB->PRCR = 0x00
            | (0x00UL << PCU_PRCR_PUE15_Pos) /* PB15 */
            | (0x00UL << PCU_PRCR_PUE14_Pos) /* PB14 */
            | (0x00UL << PCU_PRCR_PUE13_Pos) /* PB13 */
            | (0x00UL << PCU_PRCR_PUE12_Pos) /* PB12 */
            | (0x00UL << PCU_PRCR_PUE11_Pos) /* PB11 */
            | (0x00UL << PCU_PRCR_PUE10_Pos) /* PB10 */
            | (0x00UL << PCU_PRCR_PUE9_Pos)  /* PB9 */
            | (0x00UL << PCU_PRCR_PUE8_Pos)  /* PB8 */
            | (0x00UL << PCU_PRCR_PUE7_Pos)  /* PB7 */
            | (0x00UL << PCU_PRCR_PUE6_Pos)  /* PB6 */
            | (0x00UL << PCU_PRCR_PUE5_Pos)  /* PB5 */
            | (0x00UL << PCU_PRCR_PUE4_Pos)  /* PB4 */
            | (0x00UL << PCU_PRCR_PUE3_Pos)  /* PB3 */
            | (0x00UL << PCU_PRCR_PUE2_Pos)  /* PB2 */
            | (0x00UL << PCU_PRCR_PUE1_Pos)  /* PB1 */
            | (0x00UL << PCU_PRCR_PUE0_Pos); /* PB0 */


    /* PORT C setting
    PC15 : Output (Reserved)
    PC14 : Output (Reserved)
    PC13 : Output (Reserved)
    PC12 : Output (Indicated LED6)
    PC11 : Output (Indicated LED5)
    PC10 : Output (Indicated LED4)
    PC9  : Output (Indicated LED3)
    PC8  : Output (Indicated LED2)
    PC7  : Output (Indicated LED1)
    PC6  : Output (Reserved)
    PC5  : Output (Reserved)
    PC4  : Output (Reserved)
    PC3  : Output (Reserved)
    PC2  : Output (Reserved)
    PC1  : Output (Reserved)
    PC0  : Output (Reserved) */

    PC->MR2 = 0x00
            | (0x00UL << PCU_MR2_P15MUX_Pos) /* 0 : PC15,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P14MUX_Pos) /* 0 : PC14,        1 :              2 : T8IO,        3 : PFCPAO,      4 : OCIN1,       7 : */
            | (0x00UL << PCU_MR2_P13MUX_Pos) /* 0 : PC13,        1 :              2 :              3 : PRTIN1,      4 :              7 : */
            | (0x00UL << PCU_MR2_P12MUX_Pos) /* 0 : PC12,        1 :              2 :              3 : PWMUL1,      4 :              7 : */
            | (0x00UL << PCU_MR2_P11MUX_Pos) /* 0 : PC11,        1 :              2 :              3 : PWMVL1,      4 :              7 : */
            | (0x00UL << PCU_MR2_P10MUX_Pos) /* 0 : PC10,        1 :              2 :              3 : PWMWL1,      4 :              7 : */
            | (0x00UL << PCU_MR2_P9MUX_Pos)  /* 0 : PC9,         1 :              2 :              3 : PWMUH1,      4 :              7 : */
            | (0x00UL << PCU_MR2_P8MUX_Pos); /* 0 : PC8,         1 :              2 :              3 : PWMVH1,      4 :              7 : */

    PC->MR1 = 0x00
            | (0x00UL << PCU_MR1_P7MUX_Pos)  /* 0 : PC7,         1 :              2 :              3 : PWMWH1,      4 :              7 : */
            | (0x00UL << PCU_MR1_P6MUX_Pos)  /* 0 : PC6,         1 :              2 :              3 : PWMWH0,      4 :              7 : */
            | (0x00UL << PCU_MR1_P5MUX_Pos)  /* 0 : PC5,         1 :              2 :              3 : PWMVH0,      4 :              7 : */
            | (0x00UL << PCU_MR1_P4MUX_Pos)  /* 0 : PC4,         1 :              2 :              3 : PWMUH0,      4 :              7 : */
            | (0x00UL << PCU_MR1_P3MUX_Pos)  /* 0 : PC3,         1 :              2 :              3 : PWMWL0,      4 :              7 : */
            | (0x00UL << PCU_MR1_P2MUX_Pos)  /* 0 : PC2,         1 :              2 :              3 : PWMVL0,      4 :              7 : */
            | (0x00UL << PCU_MR1_P1MUX_Pos)  /* 0 : PC1,         1 :              2 :              3 : PWMUL0,      4 :              7 : */
            | (0x00UL << PCU_MR1_P0MUX_Pos); /* 0 : PC0,         1 :              2 :              3 : PRTIN0,      4 :              7 : */

    /* 0     : Push-pull output
       1     : Open-drain output
       2 / 3 : Input */
    PC->CR = 0x00
            | (0x00UL << PCU_CR_P15_Pos) /* PC15 */
            | (0x00UL << PCU_CR_P14_Pos) /* PC14 */
            | (0x00UL << PCU_CR_P13_Pos) /* PC13 */
            | (0x00UL << PCU_CR_P12_Pos) /* PC12 */
            | (0x00UL << PCU_CR_P11_Pos) /* PC11 */
            | (0x00UL << PCU_CR_P10_Pos) /* PC10 */
            | (0x00UL << PCU_CR_P9_Pos)  /* PC9 */
            | (0x00UL << PCU_CR_P8_Pos)  /* PC8 */
            | (0x00UL << PCU_CR_P7_Pos)  /* PC7 */
            | (0x00UL << PCU_CR_P6_Pos)  /* PC6 */
            | (0x00UL << PCU_CR_P5_Pos)  /* PC5 */
            | (0x00UL << PCU_CR_P4_Pos)  /* PC4 */
            | (0x00UL << PCU_CR_P3_Pos)  /* PC3 */
            | (0x00UL << PCU_CR_P2_Pos)  /* PC2 */
            | (0x00UL << PCU_CR_P1_Pos)  /* PC1 */
            | (0x00UL << PCU_CR_P0_Pos); /* PC0 */

    /* 0 / 1 : Disable pull-up/down resistor
           2 : Enable pull-up resistor
           3 : Enable Pull-down resistor */
    PC->PRCR = 0x00
            | (0x00UL << PCU_PRCR_PUE15_Pos) /* PC15 */
            | (0x00UL << PCU_PRCR_PUE14_Pos) /* PC14 */
            | (0x00UL << PCU_PRCR_PUE13_Pos) /* PC13 */
            | (0x00UL << PCU_PRCR_PUE12_Pos) /* PC12 */
            | (0x00UL << PCU_PRCR_PUE11_Pos) /* PC11 */
            | (0x00UL << PCU_PRCR_PUE10_Pos) /* PC10 */
            | (0x00UL << PCU_PRCR_PUE9_Pos)  /* PC9 */
            | (0x00UL << PCU_PRCR_PUE8_Pos)  /* PC8 */
            | (0x00UL << PCU_PRCR_PUE7_Pos)  /* PC7 */
            | (0x00UL << PCU_PRCR_PUE6_Pos)  /* PC6 */
            | (0x00UL << PCU_PRCR_PUE5_Pos)  /* PC5 */
            | (0x00UL << PCU_PRCR_PUE4_Pos)  /* PC4 */
            | (0x00UL << PCU_PRCR_PUE3_Pos)  /* PC3 */
            | (0x00UL << PCU_PRCR_PUE2_Pos)  /* PC2 */
            | (0x00UL << PCU_PRCR_PUE1_Pos)  /* PC1 */
            | (0x00UL << PCU_PRCR_PUE0_Pos); /* PC0 */


    /* PORT D setting 
    PD15 : Output (Reserved)
    PD14 : Output (Reserved)
    PD13 : Output (Reserved)
    PD12 : Output (Reserved)
    PD11 : Output (Reserved)
    PD10 : Output (Reserved)
    PD9  : Output (Reserved)
    PD8  : Output (Reserved)
    PD7  : Output (Reserved)
    PD6  : Output (Reserved)
    PD5  : Output (Reserved)
    PD4  : Output (Reserved)
    PD3  : RXD0 ()
    PD2  : TXD0 ()
    PD1  : Output (Reserved)
    PD0  : Output (Reserved) */

    PD->MR2 = 0x00
            | (0x00UL << PCU_MR2_P15MUX_Pos) /* 0 : PD15,        1 :              2 :              3 :              4 :              7 : AN21/CP0A/CP2B */
            | (0x00UL << PCU_MR2_P14MUX_Pos) /* 0 : PD14,        1 :              2 :              3 :              4 :              7 : AN20 */
            | (0x00UL << PCU_MR2_P13MUX_Pos) /* 0 : PD13,        1 :              2 :              3 :              4 :              7 : AN19 */
            | (0x00UL << PCU_MR2_P12MUX_Pos) /* 0 : PD12,        1 :              2 :              3 :              4 :              7 : AN17/CP1A/CP3B */
            | (0x00UL << PCU_MR2_P11MUX_Pos) /* 0 : PD11,        1 :              2 :              3 :              4 :              7 : AN16/CP2A/CP0B */
            | (0x00UL << PCU_MR2_P10MUX_Pos) /* 0 : PD10,        1 :              2 :              3 :              4 :              7 : AN15/CP3A/CP1B */
            | (0x00UL << PCU_MR2_P9MUX_Pos)  /* 0 : PD9,         1 :              2 :              3 :              4 :              7 : AN13*/
            | (0x00UL << PCU_MR2_P8MUX_Pos); /* 0 : PD8,         1 :              2 :              3 :              4 :              7 : AN12*/

    PD->MR1 = 0x00
            | (0x00UL << PCU_MR1_P7MUX_Pos)  /* 0 : PD7,         1 :              2 :              3 :              4 :              7 : AN11 */
            | (0x00UL << PCU_MR1_P6MUX_Pos)  /* 0 : PD6,         1 :              2 :              3 :              4 :              7 : AN10 */
            | (0x00UL << PCU_MR1_P5MUX_Pos)  /* 0 : PD5,         1 :              2 :              3 :              4 :              7 : AN9 */
            | (0x00UL << PCU_MR1_P4MUX_Pos)  /* 0 : PD4,         1 :              2 :              3 :              4 :              7 : AN0 */
            | (0x03UL << PCU_MR1_P3MUX_Pos)  /* 0 : PD3,         1 : MISO0,       2 : T7IO,        3 : RXD0,        4 : CP2OUT,      7 : */
            | (0x03UL << PCU_MR1_P2MUX_Pos)  /* 0 : PD2,         1 : MOSI0,       2 : T6IO,        3 : TXD0,        4 : CP1OUT,      7 : */
            | (0x00UL << PCU_MR1_P1MUX_Pos)  /* 0 : PD1,         1 : SCK0,        2 : T5IO,        3 : PFCPPRT,     4 : CP0OUT,      7 : */
            | (0x00UL << PCU_MR1_P0MUX_Pos); /* 0 : PD0,         1 : SS0,         2 : T9IO,        3 : PFCPBO,      4 : CP3OUT,      7 : */

    /* 0     : Push-pull output
       1     : Open-drain output
       2 / 3 : Input */
    PD->CR = 0x00
            | (0x00UL << PCU_CR_P15_Pos) /* PD15 */
            | (0x00UL << PCU_CR_P14_Pos) /* PD14 */
            | (0x00UL << PCU_CR_P13_Pos) /* PD13 */
            | (0x00UL << PCU_CR_P12_Pos) /* PD12 */
            | (0x00UL << PCU_CR_P11_Pos) /* PD11 */
            | (0x00UL << PCU_CR_P10_Pos) /* PD10 */
            | (0x00UL << PCU_CR_P9_Pos)  /* PD9 */
            | (0x00UL << PCU_CR_P8_Pos)  /* PD8 */
            | (0x00UL << PCU_CR_P7_Pos)  /* PD7 */
            | (0x00UL << PCU_CR_P6_Pos)  /* PD6 */
            | (0x00UL << PCU_CR_P5_Pos)  /* PD5 */
            | (0x00UL << PCU_CR_P4_Pos)  /* PD4 */
            | (0x03UL << PCU_CR_P3_Pos)  /* PD3 */
            | (0x00UL << PCU_CR_P2_Pos)  /* PD2 */
            | (0x00UL << PCU_CR_P1_Pos)  /* PD1 */
            | (0x00UL << PCU_CR_P0_Pos); /* PD0 */

    /* 0 / 1 : Disable pull-up/down resistor
           2 : Enable pull-up resistor
           3 : Enable Pull-down resistor */
    PD->PRCR = 0x00
            | (0x00UL << PCU_PRCR_PUE15_Pos) /* PD15 */
            | (0x00UL << PCU_PRCR_PUE14_Pos) /* PD14 */
            | (0x00UL << PCU_PRCR_PUE13_Pos) /* PD13 */
            | (0x00UL << PCU_PRCR_PUE12_Pos) /* PD12 */
            | (0x00UL << PCU_PRCR_PUE11_Pos) /* PD11 */
            | (0x00UL << PCU_PRCR_PUE10_Pos) /* PD10 */
            | (0x00UL << PCU_PRCR_PUE9_Pos)  /* PD9 */
            | (0x00UL << PCU_PRCR_PUE8_Pos)  /* PD8 */
            | (0x00UL << PCU_PRCR_PUE7_Pos)  /* PD7 */
            | (0x00UL << PCU_PRCR_PUE6_Pos)  /* PD6 */
            | (0x00UL << PCU_PRCR_PUE5_Pos)  /* PD5 */
            | (0x00UL << PCU_PRCR_PUE4_Pos)  /* PD4 */
            | (0x00UL << PCU_PRCR_PUE3_Pos)  /* PD3 */
            | (0x00UL << PCU_PRCR_PUE2_Pos)  /* PD2 */
            | (0x00UL << PCU_PRCR_PUE1_Pos)  /* PD1 */
            | (0x00UL << PCU_PRCR_PUE0_Pos); /* PD0 */


    /* PORT E setting
    PE15 : Output (Reserved)
    PE14 : Output (Reserved)
    PE13 : Output (Reserved)
    PE12 : Output (Reserved)
    PE11 : Output (Reserved)
    PE10 : Output (Reserved)
    PE9  : Output (Reserved)
    PE8  : Output (Reserved)
    PE7  : Output (Reserved)
    PE6  : Output (Reserved)
    PE5  : Output (Reserved)
    PE4  : Output (Reserved)
    PE3  : Output (Reserved)
    PE2  : Output (Reserved)
    PE1  : Output (Reserved)
    PE0  : Output (Reserved) */

    PE->MR2 = 0x00
            | (0x00UL << PCU_MR2_P15MUX_Pos) /* 0 : PE15,        1 : RXD4,        2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P14MUX_Pos) /* 0 : PE14,        1 : TXD4,        2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P13MUX_Pos) /* 0 : PE13,        1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P12MUX_Pos) /* 0 : PE12,        1 : SS1,         2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P11MUX_Pos) /* 0 : PE11,        1 : SCK1,        2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P10MUX_Pos) /* 0 : PE10,        1 : MISO1,       2 :              3 : RXD3,        4 :              7 : */
            | (0x00UL << PCU_MR2_P9MUX_Pos)  /* 0 : PE9,         1 : MOSI1,       2 : T6IO,        3 : TXD3,        4 :              7 : */
            | (0x00UL << PCU_MR2_P8MUX_Pos); /* 0 : PE8,         1 :              2 : T5IO,        3 :              4 :              7 : */

    PE->MR1 = 0x00
            | (0x00UL << PCU_MR1_P7MUX_Pos)  /* 0 : PE7,         1 :              2 : T4IO,        3 : PFCPBO,      4 :              7 : */
            | (0x00UL << PCU_MR1_P6MUX_Pos)  /* 0 : PE6,         1 : MISO1,       2 : T3IO,        3 : PFCPAO,      4 :              7 : */
            | (0x00UL << PCU_MR1_P5MUX_Pos)  /* 0 : PE5,         1 : MOSI1,       2 : T2IO,        3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P4MUX_Pos)  /* 0 : PE4,         1 : SDA0,        2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P3MUX_Pos)  /* 0 : PE3,         1 : SCL0,        2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P2MUX_Pos)  /* 0 : PE2,         1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P1MUX_Pos)  /* 0 : PE1,         1 :              2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P0MUX_Pos); /* 0 : PE0,         1 :              2 :              3 :              4 :              7 : */

    /* 0     : Push-pull output
       1     : Open-drain output
       2 / 3 : Input */
    PE->CR = 0x00
            | (0x00UL << PCU_CR_P15_Pos) /* PE15 */
            | (0x00UL << PCU_CR_P14_Pos) /* PE14 */
            | (0x00UL << PCU_CR_P13_Pos) /* PE13 */
            | (0x00UL << PCU_CR_P12_Pos) /* PE12 */
            | (0x00UL << PCU_CR_P11_Pos) /* PE11 */
            | (0x00UL << PCU_CR_P10_Pos) /* PE10 */
            | (0x00UL << PCU_CR_P9_Pos)  /* PE9 */
            | (0x00UL << PCU_CR_P8_Pos)  /* PE8 */
            | (0x00UL << PCU_CR_P7_Pos)  /* PE7 */
            | (0x00UL << PCU_CR_P6_Pos)  /* PE6 */
            | (0x00UL << PCU_CR_P5_Pos)  /* PE5 */
            | (0x00UL << PCU_CR_P4_Pos)  /* PE4 */
            | (0x00UL << PCU_CR_P3_Pos)  /* PE3 */
            | (0x00UL << PCU_CR_P2_Pos)  /* PE2 */
            | (0x00UL << PCU_CR_P1_Pos)  /* PE1 */
            | (0x00UL << PCU_CR_P0_Pos); /* PE0 */

    /* 0 / 1 : Disable pull-up/down resistor
           2 : Enable pull-up resistor
           3 : Enable Pull-down resistor */
    PE->PRCR = 0x00
            | (0x00UL << PCU_PRCR_PUE15_Pos) /* PE15 */
            | (0x00UL << PCU_PRCR_PUE14_Pos) /* PE14 */
            | (0x00UL << PCU_PRCR_PUE13_Pos) /* PE13 */
            | (0x00UL << PCU_PRCR_PUE12_Pos) /* PE12 */
            | (0x00UL << PCU_PRCR_PUE11_Pos) /* PE11 */
            | (0x00UL << PCU_PRCR_PUE10_Pos) /* PE10 */
            | (0x00UL << PCU_PRCR_PUE9_Pos)  /* PE9 */
            | (0x00UL << PCU_PRCR_PUE8_Pos)  /* PE8 */
            | (0x00UL << PCU_PRCR_PUE7_Pos)  /* PE7 */
            | (0x00UL << PCU_PRCR_PUE6_Pos)  /* PE6 */
            | (0x00UL << PCU_PRCR_PUE5_Pos)  /* PE5 */
            | (0x00UL << PCU_PRCR_PUE4_Pos)  /* PE4 */
            | (0x00UL << PCU_PRCR_PUE3_Pos)  /* PE3 */
            | (0x00UL << PCU_PRCR_PUE2_Pos)  /* PE2 */
            | (0x00UL << PCU_PRCR_PUE1_Pos)  /* PE1 */
            | (0x00UL << PCU_PRCR_PUE0_Pos); /* PE0 */


    /* PORT F setting 
    PF15 : Output (Reserved)
    PF14 : Output (Reserved)
    PF13 : Output (Reserved)
    PF12 : Output (Reserved)
    PF11 : Output (Reserved)
    PF10 : Output (Reserved)
    PF9  : Output (Reserved)
    PF8  : Output (Reserved)
    PF7  : Output (Reserved)
    PF6  : Input (user sw2)
    PF5  : Input (user sw1)
    PF4  : Output (Reserved)
    PF3  : Output (Reserved)
    PF2  : Output (Reserved)
    PF1  : Output (Reserved)
    PF0  : Output (Reserved) */

    PF->MR2 = 0x00
            | (0x00UL << PCU_MR2_P15MUX_Pos) /* 0 : PF15,        1 :              2 : T9IO,        3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P14MUX_Pos) /* 0 : PF14,        1 : MISO1,       2 : RXD5,        3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P13MUX_Pos) /* 0 : PF13,        1 : MOSI1,       2 : TXD5,        3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P12MUX_Pos) /* 0 : PF12,        1 : SCK1,        2 :              3 :              4 :              7 : */
            | (0x00UL << PCU_MR2_P11MUX_Pos) /* 0 : PF11,        1 :              2 :              3 :              4 :              7 : AN18 */
            | (0x00UL << PCU_MR2_P10MUX_Pos) /* 0 : PF10,        1 :              2 :              3 :              4 :              7 : AN14 */
            | (0x00UL << PCU_MR2_P9MUX_Pos)  /* 0 : PF9,         1 :              2 :              3 :              4 :              7 : AN8 */
            | (0x00UL << PCU_MR2_P8MUX_Pos); /* 0 : PF8,         1 :              2 :              3 :              4 :              7 : AN7 */

    PF->MR1 = 0x00
            | (0x00UL << PCU_MR1_P7MUX_Pos)  /* 0 : PF7,         1 :              2 :              3 :              4 :              7 : AN6 */
            | (0x00UL << PCU_MR1_P6MUX_Pos)  /* 0 : PF6,         1 :              2 :              3 :              4 :              7 : AN5 */
            | (0x00UL << PCU_MR1_P5MUX_Pos)  /* 0 : PF5,         1 :              2 :              3 :              4 :              7 : AN4 */
            | (0x00UL << PCU_MR1_P4MUX_Pos)  /* 0 : PF4,         1 :              2 :              3 :              4 :              7 : AN3 */
            | (0x00UL << PCU_MR1_P3MUX_Pos)  /* 0 : PF3,         1 :              2 :              3 :              4 :              7 : AN2 */
            | (0x00UL << PCU_MR1_P2MUX_Pos)  /* 0 : PF2,         1 :              2 :              3 :              4 :              7 : AN1 */
            | (0x00UL << PCU_MR1_P1MUX_Pos)  /* 0 : PF1,         1 :              2 : T7IO,        3 :              4 :              7 : */
            | (0x00UL << PCU_MR1_P0MUX_Pos); /* 0 : PF0,         1 :              2 :              3 : PFCPOCIN,    4 :              7 : */

    /* 0     : Push-pull output
       1     : Open-drain output
       2 / 3 : Input */
    PF->CR = 0x00
            | (0x00UL << PCU_CR_P15_Pos) /* PF15 */
            | (0x00UL << PCU_CR_P14_Pos) /* PF14 */
            | (0x00UL << PCU_CR_P13_Pos) /* PF13 */
            | (0x00UL << PCU_CR_P12_Pos) /* PF12 */
            | (0x00UL << PCU_CR_P11_Pos) /* PF11 */
            | (0x00UL << PCU_CR_P10_Pos) /* PF10 */
            | (0x00UL << PCU_CR_P9_Pos)  /* PF9 */
            | (0x00UL << PCU_CR_P8_Pos)  /* PF8 */
            | (0x00UL << PCU_CR_P7_Pos)  /* PF7 */
            | (0x03UL << PCU_CR_P6_Pos)  /* PF6 */
            | (0x03UL << PCU_CR_P5_Pos)  /* PF5 */
            | (0x00UL << PCU_CR_P4_Pos)  /* PF4 */
            | (0x00UL << PCU_CR_P3_Pos)  /* PF3 */
            | (0x00UL << PCU_CR_P2_Pos)  /* PF2 */
            | (0x00UL << PCU_CR_P1_Pos)  /* PF1 */
            | (0x00UL << PCU_CR_P0_Pos); /* PF0 */

    /* 0 / 1 : Disable pull-up/down resistor
           2 : Enable pull-up resistor
           3 : Enable Pull-down resistor */
    PF->PRCR = 0x00
            | (0x00UL << PCU_PRCR_PUE15_Pos) /* PF15 */
            | (0x00UL << PCU_PRCR_PUE14_Pos) /* PF14 */
            | (0x00UL << PCU_PRCR_PUE13_Pos) /* PF13 */
            | (0x00UL << PCU_PRCR_PUE12_Pos) /* PF12 */
            | (0x00UL << PCU_PRCR_PUE11_Pos) /* PF11 */
            | (0x00UL << PCU_PRCR_PUE10_Pos) /* PF10 */
            | (0x00UL << PCU_PRCR_PUE9_Pos)  /* PF9 */
            | (0x00UL << PCU_PRCR_PUE8_Pos)  /* PF8 */
            | (0x00UL << PCU_PRCR_PUE7_Pos)  /* PF7 */
            | (0x00UL << PCU_PRCR_PUE6_Pos)  /* PF6 */
            | (0x00UL << PCU_PRCR_PUE5_Pos)  /* PF5 */
            | (0x00UL << PCU_PRCR_PUE4_Pos)  /* PF4 */
            | (0x00UL << PCU_PRCR_PUE3_Pos)  /* PF3 */
            | (0x00UL << PCU_PRCR_PUE2_Pos)  /* PF2 */
            | (0x00UL << PCU_PRCR_PUE1_Pos)  /* PF1 */
            | (0x00UL << PCU_PRCR_PUE0_Pos); /* PF0 */

    PA->ODR = 0x00000000;
    PB->ODR = 0x00000000;
    PC->ODR = 0x00001F80;
    PD->ODR = 0x00000000;
    PE->ODR = 0x00000000;
    PF->ODR = 0x00000000;
}



